/* cdLookup.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef CDLOOKUP_H
#define CDLOOKUP_H

#include "palomaDialog.h"
#include "dataset.h"

#include <gtk--.h>
#include <string>
#include <vector>
#include <set>

class CDDialog;

class CDLookup : public PalomaDialog {
public:
  // This is a vector of CDID's.  It's the set, in order, of all
  // CDs in the list.
  typedef vector<int> CDList;

  CDLookup(const Dataset &data, bool edit_mode);
  ~CDLookup();

  TableDataProxy get_cd() const;
  const CDList &get_cd_list() const;

  void popup_cd_dialog(int cd_index);

  void menu_make_playlist();
  
  Signal0 deleted;
  Signal0 accepted;

private:
  // This class is passed into cd_dialog_accepted as extra data
  // piggybacking on the CDDialog's "accept" event.  It indicates
  // the dialog pointer and the particular CD number the dialog was
  // associated with.
  class AcceptDialogData {
  public: 
    AcceptDialogData(CDDialog *dialog, int cd_index);
    CDDialog *_dialog;
    int _cd_index;
  };

  void ok_button_clicked();
  void edit_button_clicked();
  void cancel_button_clicked();
  gint clist_clicked(GdkEventButton *event);
  void cd_dialog_accepted(AcceptDialogData add);

  void layout_window();

  Gtk_ItemFactory_MenuBar _menu;
  Gtk_ObjectHandle<Gtk_MenuBar> _menubar;
  Gtk_VBox _box1;
  Gtk_ScrolledWindow _cd_window;
  Gtk_CList _clist;
  Gtk_Button _ok_button;
  Gtk_Button _edit_button;
  Gtk_Button _cancel_button;

  CDList _cd_list;

  bool _edit_mode;
};

#endif

